@@ -84,7 +84,6 @@ static shmem_startup_hook_type prev_shmem_startup_hook = NULL;
 
 
 void		_PG_init(void);
-void		_PG_fini(void);
 
 static void repmgr_shmem_startup(void);
 
@@ -133,17 +132,6 @@ _PG_init(void)
 }
 
 
-/*
- * Module unload callback
- */
-void
-_PG_fini(void)
-{
-	/* Uninstall hook */
-	shmem_startup_hook = prev_shmem_startup_hook;
-}
-
-
 /*
  * shmem_startup hook: allocate or attach to shared memory,
  */
